#ifndef FRYSPRODUKT_H
#define FRYSPRODUKT_H


#define NODERX 50
#define NODERY 10
#define TID 800
#define VOGNER 10
#define HYLLER 10


/**----Globale tabeller------------*/

double nodematriseh[NODERY][NODERX]; //Tabell for node plassering i x-retning
double nodematriseb[NODERY][NODERX]; //Tabell for node plassering i y-retning
double testfelt[NODERY][NODERX];
double forrigeX[NODERX];
double denneX[NODERX];
double nesteX[NODERX];
double kjentX[NODERX]; //Koeffisientmatriser som blir sendt til TDMA for losning
double forrigeY[NODERY];
double denneY[NODERY];
double nesteY[NODERY];
double kjentY[NODERY]; //Andre koeffisentmatriser  

double temperaturfelt[VOGNER][HYLLER][TID][NODERY][NODERX];
int tidsTab[TID]; //Tabell over lengden p tidsskrittene

/*--Globale variable---*/

int type;
double starttemp; 
double konvektivt; //Konvektivt varmeovergangstall
//double tetthet; //Tetthet til produktet [kg/m3]
int sentrumX, sentrumY; //Midterste node

typedef struct prod{ //Parametere i forbindelse med produktet
  double Hoyde; //Produkthyde
  double Bredde; //Produktbredde
  double Lengde; //Produktlengde
  double Tetthet; //Produktets tetthet kg/m3
  int nodeh; //Antall noder produktet deles opp i hyden
  int nodeb; //Antall noder produktet deles opp i bredden

  double flaterX[NODERX];
  double flaterY[NODERY];
  double konduktivitetX[NODERY][NODERX-1];
  double konduktivitetY[NODERY-1][NODERX];
  double regnHor[NODERY][NODERX];
  double regnVert[NODERY][NODERX];
  double C[NODERY][NODERX];
  int antallPro; //Antall produkt pr vogn
  int antallVogner; //Antall vogner i tunnelen
  int antallHOY; //Antall hyller pr vogn
  double starttemp; //Start temperaturen for produktene
  double sluttemp; //Temperatur for nr simuleringen skal avbryttes
  double simstopp; //Temperatur som simuleringen stopper ved
}prod;

typedef struct tider{ //tidsoppdeling for simuleringen
  int Time;
  int Min;
  int Sek;
  int omganger; //Antall simuleringsrunder for siste vogn
  long total[TID]; //Totalt antall sekunder i virkeligheten
}tider;

/*typedef struct kontab{ //Diverse kontroll variable
  int tempKor;
  int punkth;
  int punktb;
}kontab;
*/

typedef struct tun{ //Tunnel parametere
  double hast[VOGNER][HYLLER]; //Hastigheten p lufta over produktene i de enkelte produktene i tunnelen
  double temp; //Temperaturen inn p tunnelen
  double tunTemp[VOGNER][HYLLER][TID]; //Inn temperatur p produktene i forskjellige hyder og vogner
  double luftCP; //CP til lufta i tunnelen
  double luftRHO; //Tettheten til luften i tunnelen
  double luftMengde[VOGNER][HYLLER]; //Luftmengde som passerer over et produkt
  double hoyde; //Hoyde p tunnelen
  double bredde; //Bredde p tunnelen
 
}tun;

typedef struct varme{ //Tabell for varmestrmmer
 
  double varmeTab[VOGNER][HYLLER][TID]; //Tabell for varmestmmen ut fra produktet ved et gitt tidsskritt.  ETT PRODUKT
  double varmeTotalPro[VOGNER][HYLLER][TID]; //Tabell for samlet varemstrm ut av produktet. ETT PRODUKT
  double varmeTotalVogn[VOGNER][TID]; //Tabell for samlet varmestrm ut av produktene p pr vogn
  double varmeTabVogn[VOGNER][TID]; //Tabell for samlet varmestrmmen ut fra produktene p en vogn for et gitt tidspunkt
  double entalpivarme;
}varme;

typedef struct mot{ //Liste over varmemotstanden rundt produktet
  double over;
  double siden;
  double under;
}mot;

extern prod produkt;
extern tun tunnel;
extern tider simuleringstid;
//extern kontab kontrollvar;
extern varme varmestrom;
extern mot motstand;

/*---Slutt p klargjring av globale variable---*/



void simProduktFrys(int vogn,int hylle, int flytparameter); //Funksjon for aa simulere temperaturforlop og varmestrom fra produktet

/** Lager tabeller for nodenettverk og kontrollvolum. */

void frysNodenettverk (int nodehoyde, int nodebredde, int typenettverk); //Rutine for plassering av nodene

void frysKontrollvolumflater (int nodehoyde, int nodebredde); //Rutine for beregning av kontrollvolumflatene

double frysVarmeovergangstall (double hastighet, double temp); //Rutine for aa beregne varemovergangstallet mellom produkt og luft i tunnelen

void frysKonduktivitetsTabeller(int vogn, int hylle, int steg); //Funksjon for aa lage tabeller over konduktivitene til kontrollvolumene

double frysKonduktivitet (double temp1, double temp2); //Beregning av konduktivt varmeovergangstall

void startVerdier(double start, int vogn, int hylle); //Setter inn startverdier

void finnTempFelt( int vogn, int hylle, int steg); //Beregner temperaturfeltet i produktet for et tidssteg

double frysApproxH(int k, int vogn, int i, int j); //Finner den antatte endringen i entalpien. Ref[1]

void TDMA(void); //Lser for tridiagonal matriser

void VarmestromUT(int vogn, int hylle, int steg); //Beregning av varmestrmmen ut av produktet ved et gitt tidsintervall og hva den totalevarmestrmmen til det tidspunktet er


void stegGenerator(void); //Lager tabell over tidsskrittene

void tidsOmgjorer(void); //Omgjr en tid fra sekund til timer, min og sekund

double varmeUTfraENTALPIdiff(void); //Beregner total varmestrm ut fra produktet med bakgrunn i entalpidifferanser

double prosentAvvik(double varme1, double varme2); //Beregning av prosentavvik mellom to varmestrmmer

double EndringTunnelTemp(int vogn, int hylle, int steg);  //Beregning av temperaturen inn p produktvogn

void initialBeregninger(void); //Samle rutine for beregnig av diverse initalverdier og stoppbetingelser

void LuftBeregning(void); //Beregning av luftmengden som sirkulerer over produktene

void kantTemperatur(int vogn, int steg); //Legge tunneltemperaturen i temperaturfeltmatrisen fr beregning av temperaturfeltet

void testfelttunnel(double temp, int vogn, int hylle, int steg); //


void simuler(void); //Simuleringsfunksjon
#endif

/* Refferanser

[1] Pham, Q. T., 1985, A fast, unconditionally stable finite-difference scheme for heat conduction with phase change, International Journal Heat Mass Transfer, Vol 28 


*/
