#include <stdio.h>
#include <math.h>
#include "frysprodukt.h"
#include "frystermo.h"


/**---Denne filen inneholder funksjoner som beregner termodynamiske
------egenskaper til stoffer i forbindelese  med frysetunnelen.
------Opprettet 14.02.2008 Jon Arve U Engebakken-----------
------Sist endret 02.05.2008 Jon Arve U Engebakken----*/




/** 
    Dry air transport properties
*/

double DVair (double t) {//Viskositet for luft som funksjon av temperaturen.
  double dv=0;
  double p1, p2, p3 ,p4;

  p1 = 2.6667e-007;
  p2 = -0.00057714;
  p3 = 0.75962;
  p4 = 1.5429;

  dv =  p1*pow(t,3) + p2*pow(t,2) + p3*t + p4;
  dv *=1.0E-7;
  //Formlen for viskositeten er bygget p tabellverdier hentet fra 
  //Fundamentals of Heat and Mass Transfer, Frank P. Incropera, David P. DeWitt,table A.4 
  return dv;
}


double RHOair (double t) {//Tetthet for luft som funksjon av temperatur. Kalles med en temperatur i Kelvin
  double rho =0;
  double p1, p2, p3 ,p4;

  p1 = -5.02e-008;
  p2 = 6.0074e-005;
  p3 = -0.026362;
  p4 = 5.0165;

  rho = p1*pow(t,3) + p2*pow(t,2) + p3*t + p4;
  //Formlen for tettheten er bygget p tabellverdier hentet fra 
  //Fundamentals of Heat and Mass Transfer, Frank P. Incropera, David P. DeWitt,table A.4 
  return rho;
}

double CPair (double t) {//CP for luft som funksjon av temperatur. Kalles med en temperatur i Kelvin

  double cp = 0;
  double p1, p2, p3, p4, p5;

  p1 = -1.8182e-009;
  p2 = 3.1313e-006;
  p3 = -0.0015924;
  p4 = 0.35462;
  p5 = 972.06;

  cp=p1*pow(t,4) + p2*pow(t,3) + p3*pow(t,2) + p4*t + p5;
  //Formlen for cp er bygget p tabellverdier hentet fra 
  //Fundamentals of Heat and Mass Transfer, Frank P. Incropera, David P. DeWitt,table A.4 
  return cp;
}

double TCair (double t) {//Termisk konduktivitet for luft som flge av temperaturen.
  double tc = 0;
  double p1, p2, p3 ,p4;


  p1 = -1.3333e-007;
  p2 = 6e-005;
  p3 = 0.077333;
  p4 = 1.3;

  tc = p1*pow(t,3) + p2*pow(t,2) + p3*t + p4;
  //Formlen for konduktiviteten er bygget p tabellverdier hentet fra 
  //Fundamentals of Heat and Mass Transfer, Frank P. Incropera, David P. DeWitt,table A.4 
  tc *=0.0001;

  return tc;
}

double KVair (double t) {//Kinematisk viskositet som flge av temperaturen.
  double kv = 0;
  double p1, p2, p3 ,p4;

  p1 = -7.7778e-008;
  p2 = 0.00018175;
  p3 = 0.006883;
  p4 = -0.43038;

  kv = p1*pow(t,3) + p2*pow(t,2) + p3*t + p4;
  kv *=0.0000001;
  //Formlen for kinematis viskositet er bygget p tabellverdier hentet fra 
  //Fundamentals of Heat and Mass Transfer, Frank P. Incropera, David P. DeWitt,table A.4 
  return kv;

}
/**---De folgende funksjonene er kopiert fra afdutil.c
------14.02.2008  Jon Arve U Engebakken-----------*/

double DiffAir (double t) {
  double a = 188.345;
  double b = 1.28605;
  double c = 0.00168669;
  double d = -0.00000125831;
  double D = 0.0;
  
  D = a + t * (b + t * (c + t * d));
  D *=0.0000001;
  return D;
}


/** Prandtl number for air */
double PrAir (double t) {
  double Pr = 0;
  Pr =  DVair(t) * CPair(t) / TCair(t);
  return Pr;
}


/**---Slutt paa kopierte funksjoer-------*/



double TemperaturKorrigering(double entalpi){

/*Funkjson for  korrigere temperaturen som folge av entalpien
-----til produktet.
-----Sist endret 26.02.2008 Jon Arve U Engebakken
-----Funksjonen kalles med en entalpiverdi
-----Returneren en temperatur i C-------*/

  double p1, p2 ,p3 ,p4, p5, p6; //Koeffisienter
  double temp; //returverdi

  entalpi= entalpi/(1000*produkt.Tetthet);


    //Koeffisientene er funnet fra kurvetilpasning i matlab

  if (entalpi>0 ){
    temp = entalpi/(158.28/(42.2))-2.2;

  }else if(entalpi>-175.27){

    p1 = 2.4724e-011;
    p2 = 6.3328e-009;
    p3 = 9.2077e-007;
    p4 = 4.5047e-006;
    p5 = 0.0094543;
    p6 = -2.198;
  
  temp=p1*pow(entalpi,5) + p2*pow(entalpi,4) + p3*pow(entalpi,3) + p4*pow(entalpi,2) + p5*pow(entalpi,1) + p6 ;
 
 }else if(entalpi>-280.86){

  p1 = -6.9733e-010;
  p2 = -7.2134e-007;
  p3 = -0.00028819;
  p4 = -0.056829;
  p5 = -5.5326;
  p6 = -217.018;

  temp=p1*pow(entalpi,5) + p2*pow(entalpi,4) + p3*pow(entalpi,3) + p4*pow(entalpi,2) + p5*pow(entalpi,1) + p6 ;
 
 }else if(entalpi>-397.37){

   p1 = -1.5371e-011;
  p2 = -4.9261e-008;
  p3 = -5.2208e-005;
  p4 = -0.025465;
  p5 = -5.4122;
  p6 = -419.26;

  temp=p1*pow(entalpi,5) + p2*pow(entalpi,4) + p3*pow(entalpi,3) + p4*pow(entalpi,2) + p5*pow(entalpi,1) + p6 ;
   

  }else{

  p1 = -8.9721e-013;
  p2 = -2.743e-009;
  p3 = -3.3691e-006;
  p4 = -0.0020898;
  p5 = -0.10215;
  p6 = 47.775;

  temp=p1*pow(entalpi,5) + p2*pow(entalpi,4) + p3*pow(entalpi,3) + p4*pow(entalpi,2) + p5*pow(entalpi,1) + p6 ;
 
    
  }//end if entalpi
  temp = temp + 273.15;//Endrer benevingen fra C til K


  return temp;
}
/*------Slutt paa funkjsonen TemperaturKorrigering------ */


 double EntalpiAvTemperatur(double temp){

/**---Funksjonen beregner etalpien som folge av temperaturen---
------Sist endret 01.03.2008 Jon Arve U Engebakken
------Funksjonen kalles med en temperatur i K.
------Returnerer en verdi i J/m3----*/

   double entalpi;
   double p1, p2 ,p3 ,p4, p5, p6, p7, p8, p9, p10, p11; //Koeffisienter

   temp = temp-273.15;

   if (temp>(-2.2)){
     entalpi= (temp+2.2)*(158.28/(40+2.2));

   }else if(temp>(-16.420)){
    
  p1 = 0.00021501;
  p2 = 0.01533;
  p3 = 0.44341;
  p4 = 6.6839;
  p5 = 56.114;
  p6 = 261.16;
  p7 = 361.18;

  entalpi = p1*pow(temp,6) + p2*pow(temp,5) + p3*pow(temp,4) + p4*pow(temp,3) + p5*pow(temp,2) + p6*pow(temp,1) + p7;

   }else if(temp>(-80.0)){

 p1 = 1.7862e-015;
  p2 = 9.0024e-013;
  p3 = 2.0017e-010;
  p4 = 2.5888e-008;
  p5 = 2.161e-006;
  p6 = 0.00012211;
  p7 = 0.0047614;
  p8 = 0.12801;
  p9 = 2.3243;
  p10 = 28.924;
  p11 = -59.857;

  entalpi =p1*pow(temp,10) + p2*pow(temp,9) + p3*pow(temp,8) + p4*pow(temp,7) + p5*pow(temp,6) + p6*pow(temp,5) + p7*pow(temp,4) + p8*pow(temp,3) + p9*pow(temp,2) + p10*pow(temp,1) + p11;

   }else if(temp>(-273.15)){
   
     entalpi = (temp + 80.0)*(379.4651-729.28)/(80.0-273.15) - 379.4651;
   }else{ 
     printf("Feil temperaturen er under det absolutte null punkt!!!\n");
  
   }//end if temp
   entalpi=entalpi*1000*produkt.Tetthet; // Multipliserer med tettheten og 1000 for  f benevningen J/m3

 return entalpi;
 
 }
/*----Slutt paa funksjonen EntalpiAvTemperatur------**/


double CpAvTemperatur(double temp){

/*----Funksjon for beregning av spesifik varme
------Sist endret 04.03.2008 Jon Arve U Engebakken
------Kalles med en temperatur i K
------Returnerer en Cp verdi i J/(m3 K)---*/

   double p1, p2 ,p3 ,p4, p5, p6, p7, p8, p9, p10, p11; //Koeffisienter
   double CP;

   temp =temp-273.15;

   
     if(temp>(-2.2)){
       CP = 3.739;
     }else if(temp>-4.583){
        
  p1 = 1.3194e-006;
  p2 = 0.00012284;
  p3 = 0.0049625;
  p4 = 0.11403;
  p5 = 1.6415;
  p6 = 15.364;
  p7 = 93.789;
  p8 = 363.05;
  p9 = 824.7;
  p10 = 882.41;
    
   CP =  p1*pow(temp,9) + p2*pow(temp,8) + p3*pow(temp,7) + p4*pow(temp,6) + p5*pow(temp,5) + p6*pow(temp,4) + p7*pow(temp,3) + p8*pow(temp,2) + p9*pow(temp,1) + p10;
     
     }else if(temp>-14.5844){
    
  p1 = 0.0001084;
  p2 = 0.0075416;
  p3 = 0.21553;
  p4 = 3.2517;
  p5 = 27.561;
  p6 = 126.98;
  p7 = 263.07;    
    
  CP= p1*pow(temp,6) + p2*pow(temp,5) + p3*pow(temp,4) + p4*pow(temp,3) + p5*pow(temp,2) + p6*pow(temp,1) + p7;
  
  
     }else if (temp>-45.5645){
  p1 = 1.2254e-012;
  p2 = 4.746e-010;
  p3 = 7.8736e-008;
  p4 = 7.3116e-006;
  p5 = 0.00041649;
  p6 = 0.014972;
  p7 = 0.33503;
  p8 = 4.3602;
  p9 = 28.405;    
    
  CP = p1*pow(temp,8)+p2*pow(temp,7)+p3*pow(temp,6)+p4*pow(temp,5)+p5*pow(temp,4)+p6*pow(temp,3)+p7*pow(temp,2)+p8*pow(temp,1) + p9; 
  
     } else if (temp>-273.15){
    
  p1 = 5.1579e-014;
  p2 = 5.4779e-011;
  p3 = 2.3674e-008;
  p4 = 5.3431e-006;
  p5 = 0.00066919;
  p6 = 0.044933;
  p7 = 3.1139;
 
  CP = p1*pow(temp,6) + p2*pow(temp,5) + p3*pow(temp,4) + p4*pow(temp,3) + p5*pow(temp,2) + p6*pow(temp,1) + p7;
     
      }else{
       printf("Temperaturen er under det absolutte nullpunktet CP.  \n");
       }
     CP = CP*1000*produkt.Tetthet;

 return CP;
}
/*----Slutt p funksjonen CpAvTemperatur.---*/

double KonduktivitetAvTemperatur(double temp){

  /*  Funksjon for beregning av konduktiviteten for produktet for en
      gitt temperatur.
      Sist endret 27.03.2008 Jon Arve U. Engebakken
      Kalles med den temperaturen som beregningen skal gjennomfres ved, i K.
      Returnerer konduktiviteten for produket for den gitte temperaturen. */

  double p1, p2 ,p3 ,p4, p5, p6, p7, p8, p9, p10, p11; //Koeffisienter
  double svar;

  temp = temp-273.15;


  if(temp>-2.2){
    p1 = -5.7058e-006;
    p2 = 0.0016464;
    p3 = 0.50087;

      svar = p1*pow(temp,2) + p2*temp + p3 ;
  }else if (temp>-13.053){
    
    p1 = -1.7348e-010;
    p2 = -2.5719e-008;
    p3 = -1.6028e-006;
    p4 = -5.5187e-005;
    p5 = -0.0011587;
    p6 = -0.01543;
    p7 = -0.13129;
    p8 = -0.70087;
    p9 = -2.2401;
    p10 = -2.1273;
  
    svar = p1*pow(temp,9) + p2*pow(temp,8) + p3*pow(temp,7) + p4*pow(temp,6) + p5*pow(temp,5) + p6*pow(temp,4) + p7*pow(temp,3) + p8*pow(temp,2) + p9*pow(temp,1) + p10;

  }else{
  
    p1 = -8.6679e-014;
    p2 = -7.8391e-011;
    p3 = -2.7691e-008;
    p4 = -4.8392e-006;
    p5 = -0.00036389;
    p6 = -0.02388;
    p7 = 1.3102;
  
    svar =  p1*pow(temp,6) + p2*pow(temp,5) + p3*pow(temp,4) + p4*pow(temp,3) + p5*pow(temp,2) + p6*pow(temp,1) + p7;
  }//end if
  
  return svar;

}//---Slutt p funksjonen ---KonduktivitetAvTemperatur-----
